//
// Options for pcb-gcode.ulp.
// Often used options are at the top of the file.
//
// author=John Johnson
// description=Mach
//

string DEFAULT_EXTENSION = ".nc";
int FILENAMES_8_CHARACTERS = NO;

// 
// Format strings for coordinates, etc.
//
string FORMAT = "%-6.4f ";      /* coordinate format */
string FR_FORMAT = "F%-5.2f "; 	/* feedrate format */
string IJ_FORMAT = "I" + FORMAT + "J" + FORMAT;
string EOL = "\n";				  		/* standard line ending */
string PARAM = "P";							/* some use P, some # for parameters */

//
// Modes
//
string INCH_MODE = "G20" + EOL;
string METRIC_MODE = "G21" + EOL;
string MIL_MODE = "M02 (Please setup MIL_MODE in gcode-defaults.h)" + EOL;
string MICRON_MODE = "M02 (Please setup MICRON_MODE in gcode-defaults.h)" + EOL;
string ABSOLUTE_MODE = "G90" + EOL;

//
// G codes
//
string RAPID = "G00 ";
string FEED = "G01 ";
string ARC_CW = "G02 ";
string ARC_CCW = "G03 ";
string DWELL = "G04 " + PARAM + "%f" + EOL;

//
// M codes
//
string SPINDLE_ON = "M03" + EOL + DWELL;
string SPINDLE_OFF = "M05" + EOL;
string END_PROGRAM = "M02" + EOL;
string OPERATOR_PAUSE = "M06 ";

//
// Other
//
string TOOL_CODE = "T%02d ";

//
// Coordinates
//
string MOVE_XY = "X" + FORMAT + "Y" + FORMAT;
string MOVE_Z = "Z" + FORMAT;
string MOVE_XYZ = MOVE_XY + MOVE_Z;

//
// Rapids
//
string RAPID_MOVE_XY = RAPID + MOVE_XY + EOL;
string RAPID_MOVE_XY_HOME = RAPID + "X0 Y0" + EOL;
string RAPID_MOVE_Z = RAPID + MOVE_Z + EOL;
string RAPID_MOVE_XYZ = RAPID + MOVE_XY + MOVE_Z + EOL;

//
// Feeds
//
string FEED_MOVE_XY = FEED + MOVE_XY + EOL;
string FEED_MOVE_XY_WITH_RATE = FEED + MOVE_XY + FR_FORMAT;
string FEED_MOVE_Z = FEED + MOVE_Z + EOL;
string FEED_MOVE_Z_WITH_RATE = FEED + MOVE_Z + FR_FORMAT + EOL;

//
// Drilling holes
//
// G82 Xx.xxx Yy.yyy Z.zzz Fff.f Rr.rrr #dwell
//
string DRILL_CODE = "G82 ";
string RELEASE_PLANE = "R" + FORMAT;
string DWELL_TIME = PARAM + "%f";
string DRILL_FIRST_HOLE = DRILL_CODE + MOVE_XYZ + FR_FORMAT + RELEASE_PLANE + DWELL_TIME + EOL;
string DRILL_HOLE = DRILL_CODE + MOVE_XY + EOL;

//
// Tool change
//
string TOOL_CHANGE = OPERATOR_PAUSE + TOOL_CODE + " ; " + FORMAT + EOL;


//
// Circles / Arcs
//
string CIRCLE_TOP = ARC_CW + MOVE_XY + IJ_FORMAT + EOL;
string CIRCLE_BOTTOM = ARC_CCW + MOVE_XY + IJ_FORMAT + EOL;

//
// Misc
//
string COMMENT_BEGIN = "(";
string COMMENT_END = ")";

