#include "pcb-gcode.h"
#include "pcb-defaults.h"
#include "pcb-machine.h"
#include "gcode-defaults.h"
#include "pcb-gcode-options.h"
#include "user-gcode.h"

void output_file_heading()
{
	printf("%s This gcode generated by %s %s\n"
		"%s Copyright 2005 by John Johnson. See readme.txt for licensing terms. %s\n",
		COMMENT_BEGIN, argv[PROGRAM_NAME_ARG], COMMENT_END,
		COMMENT_BEGIN, COMMENT_END
		);
		
	if (NC_FILE_COMMENT_FROM_BOARD) {
		board(B) {
			printf("\n%s This file generated from the board %s %s\n", COMMENT_BEGIN, B.name, COMMENT_END);
		}
	}
	
	if (NC_FILE_COMMENT_DATE) {
		printf("%s This file generated %s %s\n", COMMENT_BEGIN, t2string(time()), COMMENT_END);
	}
	
	if (NC_FILE_COMMENT_MACHINE_SETTINGS) {
		printf("\n%s Settings from pcb-machine.h %s\n", COMMENT_BEGIN, COMMENT_END);
		printf("%s tool size = %6.4f %s\n", COMMENT_BEGIN, width, COMMENT_END);
		printf("%s z high = %6.4f\tz up = %6.4f\tz down = %6.4f %s\n", 
			COMMENT_BEGIN, DEFAULT_Z_HIGH, DEFAULT_Z_UP, DEFAULT_Z_DOWN, COMMENT_END);
		printf("%s drill depth = %6.4f %s\n", COMMENT_BEGIN, DRILL_DEPTH, COMMENT_END);
		printf("%s spindle on time = %6.4f %s\n", COMMENT_BEGIN, SPINDLE_ON_TIME, COMMENT_END);
		printf("%s milling depth = %6.4f %s\n", 	 COMMENT_BEGIN, MILLING_DEPTH, COMMENT_END);
		printf("%s tool change at X%6.4f, Y%6.4f, Z%6.4f %s\n", 
			COMMENT_BEGIN, TOOL_CHANGE_POS_X, TOOL_CHANGE_POS_Y, TOOL_CHANGE_POS_Z, COMMENT_END);
		printf("%s feed rate = %6.4f\tfeed rate z = %6.4f %s\n", 
			COMMENT_BEGIN, FEED_RATE, FEED_RATE_Z, COMMENT_END);
	}

	if (NC_FILE_COMMENT_PCB_DEFAULTS_SETTINGS) {
		printf("\n%s Settings from pcb-defaults.h %s\n", COMMENT_BEGIN, COMMENT_END);
		printf("%s Default isolate = %6.4f %s\n", COMMENT_BEGIN, DEFAULT_ISOLATE, COMMENT_END);
		printf("%s isolate max = %6.4f %s\n", COMMENT_BEGIN, ISO_MAX, COMMENT_END);
		printf("%s isolate step = %6.4f %s\n", COMMENT_BEGIN, ISO_STEP, COMMENT_END);
		printf("%s Generated: %s%s%s%s%s%s %s\n", COMMENT_BEGIN,
			(GENERATE_TOP_OUTLINES) ? "top outlines, " : "",
			(GENERATE_TOP_DRILL) ? "top drill, " : "",
			(GENERATE_TOP_FILL) ? "top fill, " : "",
			(GENERATE_BOTTOM_OUTLINES) ? "bottom outlines, " : "",
			(GENERATE_BOTTOM_DRILL) ? "bottom drill, " : "",
			(GENERATE_BOTTOM_FILL) ? "bottom fill" : "",
			COMMENT_END);
		printf("%s Unit of measure: %s %s\n", COMMENT_BEGIN, UNIT_OF_MEASURE, COMMENT_END);
		printf("\n");
	}
	
	printf("\n");
}

void output_file_closing()
{
	printf("(File Footer)\n");
}

// Kinds (outline, drill, etc.)
void output_kind_begin()
{
	if (USER_GCODE == NO)
		return;
		
	switch (g_phase) {
		case PH_TOP_OUT_WRITE:
		case PH_BOTTOM_OUT_WRITE:
			printf(OUTLINE_BEGIN[ALL]);
			printf(OUTLINE_BEGIN[side]);
			break;

		case PH_TOP_DRILL:
		case PH_BOTTOM_DRILL:
			printf(DRILL_BEGIN[ALL]);
			printf(DRILL_BEGIN[side]);
			break;

		case PH_TOP_FILL_WRITE:
		case PH_BOTTOM_FILL_WRITE:
			printf(FILL_BEGIN[ALL]);
			printf(FILL_BEGIN[side]);
			break;

		case PH_MILL:
			printf(MILL_BEGIN[ALL]);
			printf(MILL_BEGIN[side]);
			break;
		default:
			dlgMessageBox("!Unknown g_phase " + int_to_string(g_phase) 
					+ " in output_kind_begin()");
	}
}

void output_between_outline_passes()
{
	if (USER_GCODE) {
		printf(OUTLINE_BETWEEN[ALL]);
		printf(OUTLINE_BETWEEN[side]);
	}
}

void output_kind_end()
{
	if (USER_GCODE == NO)
		return;

	switch (g_phase) {
		case PH_TOP_OUT_WRITE:
		case PH_BOTTOM_OUT_WRITE:
			printf(OUTLINE_END[side]);
			printf(OUTLINE_END[ALL]);
			break;

		case PH_TOP_DRILL:
		case PH_BOTTOM_DRILL:
			printf(DRILL_END[side]);
			printf(DRILL_END[ALL]);
			break;

		case PH_TOP_FILL_WRITE:
		case PH_BOTTOM_FILL_WRITE:
			printf(FILL_END[side]);
			printf(FILL_END[ALL]);
			break;

		case PH_MILL:
			printf(MILL_END[side]);
			printf(MILL_END[ALL]);
			break;
		default:
			dlgMessageBox("!Unknown g_phase " + int_to_string(g_phase) 
					+ " in output_kind_end()");
	}
}

// Tool changing
void output_tool_change_begin()
{
	if (USER_GCODE) {
		printf(TOOL_CHANGE_BEGIN[ALL]);
		printf(TOOL_CHANGE_BEGIN[side]);
	}
}

void output_tool_changed()
{
	if (USER_GCODE) {
		printf(TOOL_CHANGED[side]);
		printf(TOOL_CHANGED[ALL]);
	}
}

void output_tool_zero_begin()
{
	if (USER_GCODE) {
		printf(TOOL_ZERO_BEGIN[ALL]);
		printf(TOOL_ZERO_BEGIN[side]);
	}
}

void output_tool_zero_end()
{
	if (USER_GCODE) {
		printf(TOOL_ZERO_END[side]);
		printf(TOOL_ZERO_END[ALL]);
	}
}

void output_tool_change_end()
{
	if (USER_GCODE) {
		printf(TOOL_CHANGE_END[side]);
		printf(TOOL_CHANGE_END[ALL]);
	}
}

//
// Print file beginning headers and user-codes.
//
void output_file_preamble()
{
	output_file_heading();

	if (USER_GCODE) {
		printf(FILE_BEGIN[ALL]);
		printf(FILE_BEGIN[side]);
		output_kind_begin();
	}
}

//
// Print file closing text and user-codes.
//
void output_file_postamble()
{
	if (USER_GCODE) {
		output_kind_end();
		printf(FILE_END[side]);
		printf(FILE_END[ALL]);
	}

	output_file_closing();
}
